# Eventarc API Logging Integration

The proto files in this directory serve as documentation for the format of the logs for the [Eventarc API](https://cloud.google.com/eventarc/docs).
These are not currently published as libraries. (Libraries may be available in some languages where appropriate, but not to the same degree of coverage as the Google Cloud Client Libraries used to make API calls.)
Language-specific options may be added later, in order to facilitate library publication.
